@@ -12,6 +12,7 @@ class TestScrapersSubnational:
         BaseScraper.population_lookup = {}
         today = parse_date("2020-10-01")
         adminlevel = AdminLevel(configuration)
+        adminlevel.setup_from_admin_info(configuration["admin_info"])
         level = "subnational"
         scraper_configuration = configuration[f"scraper_{level}"]
         runner = Runner(("AFG",), today)
@@ -353,6 +354,7 @@ class TestScrapersSubnational:
         BaseScraper.population_lookup = {}
         today = parse_date("2020-10-01")
         adminlevel = AdminLevel(configuration["admin1"])
+        adminlevel.setup_from_admin_info(configuration["admin1"]["admin_info"])
         level = "subnational"
         scraper_configuration = configuration[f"scraper_{level}"]
         runner = Runner(("SOM",), today)
@@ -405,6 +407,7 @@ class TestScrapersSubnational:
         )
 
         adminlevel = AdminLevel(configuration["admin2"])
+        adminlevel.setup_from_admin_info(configuration["admin2"]["admin_info"])
         runner = Runner(("SOM",), today)
         runner.add_configurables(
             scraper_configuration, level, adminlevel=adminlevel
